<?php
/**
 * Genesis Framework.
 *
 * WARNING: This file is part of the core Genesis Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package StudioPress\Genesis
 * @author  StudioPress
 * @license GPL-2.0-or-later
 * @link    https://my.studiopress.com/themes/genesis/
 */

$people = require GENESIS_CONFIG_DIR . '/contributors.php';
$genesis_contributors = new Genesis_Contributors( $people );
$genesis_allowed_code = array(
		'code' => array(),
		'a'    => array( 'href' => array() ),
);
?>
<div class="wrap about-wrap">

<img src="<?php echo esc_attr( get_template_directory_uri() . '/lib/admin/images/whats-new.png' ); ?>" class="alignright whats-new" />

<h1><?php echo esc_html( get_admin_page_title() ); ?></h1>

<p class="about-text"><?php esc_html_e( 'In addition to the typical bug fixes and performance enhancements, Genesis 2.7 is focused on updating some key architectural components, and is aimed at modernizing the codebase to prepare for some exciting future updates.', 'genesis' ); ?></p>

<div class="changelog">
	<div class="feature-section">
		<h2 class="screen-reader-text"><?php _e( 'Changes', 'genesis' ); ?></h2>

		<h3><?php esc_html_e( 'Preparing for WordPress 5.0', 'genesis' ); ?></h3>
		<p><?php esc_html_e( 'WordPress 5.0 is just around the corner, and we want to make sure your site is prepared!', 'genesis' ) ; ?></p>
		<p><?php esc_html_e( 'Although Genesis 2.7 does not include any features that directly rely on WordPress 5.0 or the Gutenberg editor, we have spent a great deal of time preparing the Genesis code structure for new features that definitely will integrate with WordPress 5.0.', 'genesis' ) ; ?></p>

		<h3><?php esc_html_e( 'PHP 5.3', 'genesis' ); ?></h3>
		<p><?php esc_html_e( 'Genesis 2.7 requires PHP version 5.3 or greater in order to function properly.', 'genesis' ) ; ?></p>
		<p><?php esc_html_e( 'Why?', 'genesis' ) ; ?></p>
		<p><?php esc_html_e( 'Because we\'re trying to be good internet citizens! And though we can\'t jump immediately to requiring PHP 7.2, we are beginning to slowly increase our minimum requirements in Genesis, to encourage users to upgrade outdated PHP versions, as well as give ourselves the ability to create cool new features that rely on the more modern tools available only in more modern versions of PHP.', 'genesis' ) ; ?></p>

		<h3><?php esc_html_e( 'More Modern Architecture', 'genesis' ); ?></h3>
		<p><p><?php esc_html_e( 'Genesis is nearly a decade old! Which means that it uses some coding methods that could use a modern refresh.', 'genesis' ) ; ?></p>
		<p><?php esc_html_e( 'We may not be able to modernize the entire codebase in one release, but we can make it better and better each time we release an update. And that\'s exactly what we did in Genesis 2.7.', 'genesis' ) ; ?></p>
		<p><?php esc_html_e( 'We began moving code to classes where appropriate, and are moving more and more of the default Genesis behavior toward easy to read configuration files.', 'genesis' ) ; ?></p>
		<p><?php esc_html_e( 'We think this is a worthy investment in the long-term quality and maintainability of the Genesis Framework, clearing the way for newer experiences and better products in the Genesis ecosystem.', 'genesis' ) ; ?></p>

		<h3><?php esc_html_e( 'The Details', 'genesis' ); ?></h3>
		<p><?php printf( wp_kses( __( 'We keep a detailed changelog for each release. The changelog for Genesis 2.7 can be found <a href="%s">here</a>.', 'genesis' ), $genesis_allowed_code ), 'https://studiopress.github.io/genesis/changelog/2.7.0' ); ?></p>

	</div>
</div>

<div class="project-leads">

	<h2><?php _e( 'Project Leads', 'genesis' ); ?></h2>

	<ul class="wp-people-group " id="wp-people-group-project-leaders">
		<?php
		$lead_developers = $genesis_contributors->find_by_role( 'lead-developer' );
		array_walk( $lead_developers, function( Genesis_Contributor $person ) {
			printf(
				'<li class="wp-person">' .
				'<a href="%1$s"><img src="%2$s" alt="%3$s" class="gravatar" /></a><a class="web" href="%1$s">%4$s</a>' .
				'<span class="title">%5$s</span>' .
				'</li>' . "\n",
				esc_url( $person->get_profile_url() ),
				esc_url( $person->get_avatar_url() ),
				esc_attr( $person->get_name() ),
				esc_html( $person->get_name() ),
				esc_html( $person->get_named_role() )
			);
		});
		?>
	</ul>

</div>

<div class="contributors">

	<h2><?php _e( 'Contributors', 'genesis' ); ?></h2>

	<ul class="wp-people-group" id="wp-people-group-contributing-developers">
		<?php
		$contributors = $genesis_contributors->find_contributors();
		array_walk( $contributors, function( Genesis_Contributor $person ) {
			printf(
				'<li class="wp-person">' .
				'<a href="%1$s"><img src="%2$s" alt="%3$s" class="gravatar" /></a><a class="web" href="%1$s">%4$s</a>' .
				'<span class="title">%5$s</span>' .
				'</li>' . "\n",
				esc_url( $person->get_profile_url() ),
				esc_url( $person->get_avatar_url() ),
				esc_attr( $person->get_name() ),
				esc_html( $person->get_name() ),
				esc_html( $person->get_named_role() )
			);
		});
		?>
	</ul>

</div>

<div class="return-to-dashboard">
	<p><a href="<?php echo esc_url( menu_page_url( 'genesis', 0 ) ); ?>"><?php _e( 'Go to Theme Settings &rarr;', 'genesis' ); ?></a></p>
	<?php if ( ! genesis_seo_disabled() ) : ?>
	<p><a href="<?php echo esc_url( menu_page_url( 'seo-settings', 0 ) ); ?>"><?php _e( 'Go to SEO Settings &rarr;', 'genesis' ); ?></a></p>
	<?php endif; ?>

</div>

</div>
